seqtools.split_sequence_extended_to_weights_without_overhang
============================================================

.. autofunction:: abjad.tools.seqtools.split_sequence_extended_to_weights_without_overhang
